@@ -2,7 +2,7 @@ package Mojo::Phantom;
 
 use Mojo::Base -base;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 $VERSION = eval $VERSION;
 
 use Mojo::Phantom::Process;
@@ -25,6 +25,9 @@ has cookies => sub { [] };
 has package => 'main';
 has 'setup';
 has sep     => '--MOJO_PHANTOM_MSG--';
+has no_exit => 0;
+has note_console => 0;
+has 'exe';
 
 has template => <<'TEMPLATE';
   % my ($self, $url, $js) = @_;
@@ -77,6 +80,24 @@ has template => <<'TEMPLATE';
   var page = require('webpage').create();
   page.onError = onError;
 
+  % if($self->note_console) {
+  
+    // redirect browser console log to TAP
+    page.onConsoleMessage = function(msg) {
+      perl.note('js console: ' + msg);
+    };
+
+    // redirect console log to TAP
+    (function() {
+      var old = console.log;
+      console.log = function(msg) {
+        perl.note('phantom console: ' + msg);
+        old.apply(this, Array.prototype.slice.call(arguments));
+      };
+    }());
+  
+  % }
+
   // Additional setup
   <%= $self->setup || '' %>;
 
@@ -84,7 +105,9 @@ has template => <<'TEMPLATE';
 
     <%= $js %>;
 
-    phantom.exit();
+    % unless($self->no_exit) {
+      phantom.exit();
+    % }
   });
 TEMPLATE
 
@@ -93,6 +116,7 @@ sub execute_file {
   # note that $file might be an object that needs to have a strong reference
 
   my $proc = Mojo::Phantom::Process->new;
+  $proc->exe($self->exe) if $self->exe;
 
   my $sep = $self->sep;
   my $package = $self->package;
@@ -226,6 +250,24 @@ It takes as its arguments the instance, a target url, and a string of javascript
 
 The default handles much of what this module does, you should be very sure of why you need to change this before doing so.
 
+=head2 no_exit
+
+Do not automatically call C<phantom.exit()> after the provided JavaScript code.  This is useful
+when testing asynchronous events.
+
+=head2 note_console
+
+Redirect C<console.log> output to TAP as note events.  This is usually helpful when writing tests.  The default is
+off for Mojo::Phantom and on for L<Test::Mojo::Role::Phantom>.
+
+=head2 exe
+
+The executable name or path to call PhantomJS.  You may substitute a compatible platform, for example using C<casperjs> to use
+CasperJS.
+
+Note that while you can use this to specify the full path of an alternate version of PhantomJS, during the install of
+Mojo::Phantom you I<must> have phantomjs in your C<PATH> for configuration and testing.
+
 =head1 METHODS
 
 L<Mojo::Phantom> inherits all methods from L<Mojo::Base> and implements the following new ones.
@@ -246,6 +288,9 @@ Takes a target url, a string of javascript to be executed in the context that th
 By default this is the page context.
 The return value is the same as L</execute_file>.
 
+The executable name or path to call PhantomJS.  You may substitute a compatible platform, for example using C<casperjs> to use
+CasperJS.
+
 =head1 NOTES
 
 NOTE that if your Perl version does not provide C<CORE::die> and C<CORE::warn>, they will be monkey-patched into the C<CORE> namespace before executing the javascript.
@@ -258,9 +303,13 @@ L<http://github.com/jberger/Test-Mojo-Phantom>
 
 Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
 
+=head1 CONTRIBUTORS
+
+Graham Ollis (plicease)
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 by Joel Berger
+Copyright (C) 2015 by L</AUTHOR> and L</CONTRIBUTORS>.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
