@@ -23,6 +23,7 @@ sub phantom_ok {
       ok    => 'Test::More::ok',
       is    => 'Test::More::is',
       diag  => 'Test::More::diag',
+      note  => 'Test::More::note',
       fail  => 'Test::More::fail',
       %{ $opts->{bind} || {} },
     );
@@ -33,6 +34,8 @@ sub phantom_ok {
       cookies => $t->ua->cookie_jar->all,
       setup   => $opts->{setup},
       package => $opts->{package} || caller,
+      no_exit => $opts->{no_exit},
+      note_console => $opts->{note_console} // 1,
     );
   };
 
@@ -178,6 +181,7 @@ The pairs passed are merged into
     ok    => 'Test::More::ok',
     is    => 'Test::More::is',
     diag  => 'Test::More::diag',
+    note  => 'Test::More::note',
     fail  => 'Test::More::fail',
   }
 
@@ -197,6 +201,15 @@ A pass-through option specifying javascript to be run after the page object is c
 
 If you need even more control, you may pass in an instance of L<Test::Mojo::Phantom> and it will be used.
 
+=item no_exit
+
+Do not automatically call C<phantom.exit()> after the provided JavaScript code.  This is useful when testing asynchronous events.
+
+=item note_console
+
+Redirect C<console.log> output to TAP as note events.  This is usually helpful, but can be turned off if it becomes too
+verbose.
+
 =back
 
 =head1 DESIGN GOALS
